the function takes in a list of positive and negative integers


list1 = pigi.sort(list1) 

Benchmarks for sorting:
(using numpy array as input)
10 million elements in 1 second with 8 GB of RAM 

btw: more RAM = Faster speeds